﻿namespace BookCatalog.Models
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using BookCatalog.Resources.Models;
    using BookCatalog.Resources.Shared;

    [Table("Catalog")]
    public class BookDetails
    {
        public int Id { get; set; }

        [Display(Name = "Title", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [StringLength(128,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Text)]
        public string Title { get; set; }

        [Display(Name = "Author", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [StringLength(128,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Text)]
        public string Author { get; set; }

        [Display(Name = "Language", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "MustSelectValue",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        public int LanguageId { get; set; }

        public int? PublisherId { get; set; }

        [Display(Name = "PublishedAt", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Date)]
        public DateTime PublishedAt { get; set; }

        [Display(Name = "Url", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [StringLength(256, MinimumLength = 11,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Url)]
        [RegularExpression(@"(http(s)?://)?([\w-]+\.)+[\w-]+(/[\w- ;,./?%&=]*)?",
            ErrorMessageResourceName = "InvalidUrl",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        public string Url { get; set; }

        [Display(Name = "Description", ResourceType = typeof(BookDetailsRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [StringLength(512, MinimumLength = 32,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.MultilineText)]
        public string Description { get; set; }

        [Display(Name = "Rating", ResourceType = typeof(BookDetailsRes))]
        [Range(1, 5,
            ErrorMessageResourceName = "ValueOutOfRange",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        public int? Rating { get; set; }

        /// <summary>Gets or sets a value indicating whether 
        /// the book is free (true) or not (false).</summary>
        [Display(Name = "IsFree", ResourceType = typeof(BookDetailsRes))]
        public bool IsFree { get; set; }

        /// <summary>Gets or sets a value indicating whether 
        /// the book is visible in the catalog (true) or not (false).</summary>
        [Display(Name = "IsVisible", ResourceType = typeof(BookDetailsRes))]
        public bool IsVisible { get; set; }

        [Display(Name = "Tags", ResourceType = typeof(BookDetailsRes))]
        public virtual ICollection<Tag> Tags { get; set; }

        [Display(Name = "Language", ResourceType = typeof(BookDetailsRes))]
        public virtual Language Language { get; set; }

        [Display(Name = "Publisher", ResourceType = typeof(BookDetailsRes))]
        public virtual Publisher Publisher { get; set; }
    }
}