﻿namespace BookCatalog.Models
{
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using BookCatalog.Resources.Models;
    using BookCatalog.Resources.Shared;

    public class Publisher
    {
        public int Id { get; set; }

        [Display(Name = "Title", ResourceType = typeof(PublisherRes))]
        [Required(ErrorMessageResourceName = "FieldIsRequired",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [StringLength(128,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Text)]
        public string Title { get; set; }

        [Display(Name = "Homepage", ResourceType = typeof(PublisherRes))]
        [StringLength(256, MinimumLength = 7,
            ErrorMessageResourceName = "InvalidStringLenght",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        [DataType(DataType.Url)]
        [RegularExpression(@"(http(s)?://)?([\w-]+\.)+[\w-]+(/[\w- ;,./?%&=]*)?",
            ErrorMessageResourceName = "InvalidUrl",
            ErrorMessageResourceType = typeof(ErrorsRes))]
        public string Homepage { get; set; }

        [Display(Name = "Books", ResourceType = typeof(PublisherRes))]
        public virtual ICollection<BookDetails> Books { get; set; }
    }
}